@@ -1,5 +1,7 @@
 import asyncio
-from typing import Any
+from typing import Awaitable, TypeVar
+
+_TReturn = TypeVar("_TReturn")
 
 
 # NOTES:
@@ -9,6 +11,7 @@ from typing import Any
 # 2. Kenny believes that we should be able to do this without a direct dependency on asyncio,
 #    by writing a loop that calls `send` on the coroutine and then returns on StopIteration.
 #    I was not able to get this working during my timeboxed window so left it like this for now.
-def wait_for_coroutine(coroutine: Any) -> Any:  # type: ignore[misc]
-    loop = asyncio.get_event_loop()
-    return loop.run_until_complete(coroutine)  # type: ignore[misc]
+def wait_for_coroutine(
+    loop: asyncio.AbstractEventLoop, coroutine: Awaitable[_TReturn]
+) -> _TReturn:
+    return loop.run_until_complete(coroutine)
